(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    130520,       2663]
NotebookOptionsPosition[    128202,       2615]
NotebookOutlinePosition[    128639,       2632]
CellTagsIndexPosition[    128596,       2629]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["1. Solar cell efficiency using back-body radiation \
[J. Appl. Phys. 32, 510 (1961)]",
 FontColor->RGBColor[0., 0.5019607843137255, 1.]]], "Subsubtitle",
 CellChangeTimes->{{3.685923090974918*^9, 3.6859231122873287`*^9}, {
  3.685924447678651*^9, 3.685924472526619*^9}, {3.6859249023724627`*^9, 
  3.685924934728939*^9}, {3.685925111043352*^9, 3.685925122117128*^9}, {
  3.717417416563408*^9, 3.717417421414874*^9}, {3.7174184740155897`*^9, 
  3.717418474828101*^9}},ExpressionUUID->"e2c70ae9-1e98-49af-8783-\
5ea05a5a9952"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Off", "[", 
   RowBox[{"NIntegrate", "::", "slwcon"}], "]"}], ";", 
  RowBox[{"Off", "[", 
   RowBox[{"NIntegrate", "::", "ncvb"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"rSun", ",", "rSE", ",", "Ts"}], "}"}], "=", 
    RowBox[{"{", 
     RowBox[{"695700", ",", 
      RowBox[{"149.6", "*", 
       SuperscriptBox["10", "6"]}], ",", "5777"}], "}"}]}], ";"}], 
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"Sun", " ", "radius", " ", 
     RowBox[{"(", "km", ")"}]}], ",", " ", 
    RowBox[{"Sun", "-", 
     RowBox[{"Earth", " ", "distance", " ", 
      RowBox[{"(", "km", ")"}]}]}], ",", " ", 
    RowBox[{"Sun", " ", "temperature", " ", 
     RowBox[{"(", "K", ")"}]}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"h", "=", 
    RowBox[{"6.6262", "*", 
     SuperscriptBox["10", 
      RowBox[{"-", "34"}]]}]}], ";", 
   RowBox[{"c", "=", 
    RowBox[{"2.99792458", "*", 
     SuperscriptBox["10", "8"]}]}], ";", 
   RowBox[{"eV", "=", 
    RowBox[{"1.60217646", "*", 
     SuperscriptBox["10", 
      RowBox[{"-", "19"}]]}]}], ";", 
   RowBox[{"kb", "=", 
    RowBox[{"1.3806488", "*", 
     SuperscriptBox["10", 
      RowBox[{"-", "23"}]]}]}], ";", 
   RowBox[{"Tc", "=", "300"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"PVlimit1", "[", 
    RowBox[{"Ts_", ",", "Tc_", ",", "Eg_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"tmp", ",", "zm", ",", "u", ",", "v", ",", "m"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     "                                                     ", 
     RowBox[{
      RowBox[{"tmp", "=", 
       RowBox[{"Log", "[", 
        RowBox[{
         FractionBox[
          RowBox[{
           SuperscriptBox["rSun", "2"], "/", 
           SuperscriptBox["rSE", "2"]}], "2"], "*", 
         FractionBox[
          RowBox[{"NIntegrate", "[", 
           RowBox[{
            FractionBox[
             SuperscriptBox["v", "2"], 
             RowBox[{
              SuperscriptBox["\[ExponentialE]", 
               FractionBox[
                RowBox[{"h", " ", "v"}], 
                RowBox[{"kb", " ", "Ts"}]]], "-", "1"}]], ",", 
            RowBox[{"{", 
             RowBox[{"v", ",", 
              FractionBox["Eg", "h"], ",", 
              SuperscriptBox["10", "15"]}], "}"}]}], "]"}], 
          RowBox[{"NIntegrate", "[", 
           RowBox[{
            FractionBox[
             SuperscriptBox["v", "2"], 
             RowBox[{
              SuperscriptBox["\[ExponentialE]", 
               FractionBox[
                RowBox[{"h", " ", "v"}], 
                RowBox[{"kb", " ", "Tc"}]]], "-", "1"}]], ",", 
            RowBox[{"{", 
             RowBox[{"v", ",", 
              FractionBox["Eg", "h"], ",", 
              SuperscriptBox["10", "15"]}], "}"}]}], "]"}]]}], "]"}]}], ";", 
      "                                                     ", 
      "\[IndentingNewLine]", 
      "                                                     ", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{
         RowBox[{"2", " ", "if", " ", "from", " ", "2"}], "-", 
         RowBox[{
         "side", " ", "emmision", " ", "from", " ", "solar", " ", "cell"}]}], 
        ";", " ", 
        RowBox[{"normal", " ", "incident"}]}], "*)"}], "\[IndentingNewLine]", 
      "                                                     ", 
      RowBox[{"zm", "=", 
       RowBox[{
        RowBox[{"ProductLog", "[", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"1", "+", "tmp"}]], "]"}], "-", "1"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      "                                                     ", 
      RowBox[{"u", "=", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          FractionBox["Eg", 
           RowBox[{"kb", " ", "Ts"}]], "*", 
          RowBox[{"NIntegrate", "[", 
           RowBox[{
            FractionBox[
             SuperscriptBox["x", "2"], 
             RowBox[{
              SuperscriptBox["\[ExponentialE]", "x"], "-", "1"}]], ",", 
            RowBox[{"{", 
             RowBox[{"x", ",", 
              FractionBox["Eg", 
               RowBox[{"kb", " ", "Ts"}]], ",", 
              SuperscriptBox["10", "2"]}], "}"}]}], "]"}]}], ")"}], "/", 
        RowBox[{"NIntegrate", "[", 
         RowBox[{
          FractionBox[
           SuperscriptBox["x", "3"], 
           RowBox[{
            SuperscriptBox["\[ExponentialE]", "x"], "-", "1"}]], ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", "0", ",", 
            SuperscriptBox["10", "2"]}], "}"}]}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      "                                                     ", 
      RowBox[{"v", "=", 
       RowBox[{
        FractionBox[
         RowBox[{"kb", " ", "Tc"}], "Eg"], "tmp"}]}], ";", 
      "\[IndentingNewLine]", 
      "                                                     ", 
      RowBox[{"m", "=", 
       RowBox[{
        FractionBox[
         SuperscriptBox["zm", "2"], 
         RowBox[{"1", "+", "zm", "-", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"-", "zm"}]]}]], "/", 
        RowBox[{"(", 
         RowBox[{"zm", "+", 
          RowBox[{"Log", "[", 
           RowBox[{"1", "+", "zm"}], "]"}]}], ")"}]}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      "                                                     ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"u", "*", "v", "*", "m"}], ",", 
        RowBox[{"v", "*", "m"}]}], "}"}]}]}], "\[IndentingNewLine]", 
    "                                                     ", "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.685846573719669*^9, 3.68584659931281*^9}, {
   3.685848440898419*^9, 3.685848443744814*^9}, {3.6858485131604176`*^9, 
   3.6858485150979476`*^9}, 3.685848555713873*^9, {3.6858485894120903`*^9, 
   3.6858487476069145`*^9}, {3.685848831480568*^9, 3.68584889078393*^9}, 
   3.6858490426187997`*^9, {3.6858492751089354`*^9, 3.6858492800791016`*^9}, 
   3.685924432763629*^9, 3.6859249822176332`*^9, {3.6859284204503236`*^9, 
   3.685928423626769*^9}, {3.6859285646683583`*^9, 3.685928570931653*^9}, {
   3.6859315424801617`*^9, 3.685931551201399*^9}, {3.6859317546177053`*^9, 
   3.6859317566348653`*^9}, {3.6859686501652546`*^9, 3.6859686606431584`*^9}, 
   3.685969945162997*^9, {3.6859701599663544`*^9, 3.6859701660349393`*^9}, {
   3.685970483383546*^9, 3.685970484920573*^9}, {3.6860771581954756`*^9, 
   3.6860771727529497`*^9}, {3.6860772384385047`*^9, 
   3.6860772490542827`*^9}, {3.686077282937642*^9, 3.686077293851616*^9}, {
   3.6860774626943436`*^9, 3.68607751035434*^9}, {3.6860776671428413`*^9, 
   3.6860777364888277`*^9}, {3.6860783428846507`*^9, 3.68607835092801*^9}, {
   3.6860785864870925`*^9, 3.6860785903406224`*^9}, {3.6861002429835596`*^9, 
   3.6861002783770485`*^9}, {3.6861010310924997`*^9, 3.686101202090761*^9}, {
   3.686101234378639*^9, 3.686101243183869*^9}, {3.6861013991736727`*^9, 
   3.6861014066825285`*^9}, 
   3.717421950187978*^9},ExpressionUUID->"18c37f0d-868c-45d3-a788-\
304d056647e3"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"fig0", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"PVlimit1", 
         StyleBox["[",
          FontWeight->"Plain"], 
         StyleBox[
          RowBox[{"Ts", ",", "Tc", ",", 
           RowBox[{"Eg", "*", "eV"}]}],
          FontWeight->"Plain"], 
         StyleBox["]",
          FontWeight->"Plain"]}], 
        StyleBox["[",
         FontWeight->"Plain"], 
        StyleBox[
         RowBox[{"[", "1", "]"}],
         FontWeight->"Plain"], 
        StyleBox["]",
         FontWeight->"Plain"]}], 
       StyleBox[",",
        FontWeight->"Plain"], 
       RowBox[{
        RowBox[{"PVlimit1", 
         StyleBox["[",
          FontWeight->"Plain"], 
         StyleBox[
          RowBox[{"Ts", ",", "Tc", ",", 
           RowBox[{"Eg", "*", "eV"}]}],
          FontWeight->"Plain"], 
         StyleBox["]",
          FontWeight->"Plain"]}], 
        StyleBox["[",
         FontWeight->"Plain"], 
        StyleBox[
         RowBox[{"[", "2", "]"}],
         FontWeight->"Plain"], 
        StyleBox["]",
         FontWeight->"Plain"]}]}], 
      StyleBox["}",
       FontWeight->"Plain"]}], ",", 
     RowBox[{"{", 
      RowBox[{"Eg", ",", "0.1", ",", "6"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"Axes", "\[Rule]", "False"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"fig2", "=", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"PVlimit1", 
       StyleBox["[",
        FontWeight->"Plain"], 
       StyleBox[
        RowBox[{"Ts", ",", "Tc", ",", 
         RowBox[{"Eg", "*", "eV"}]}],
        FontWeight->"Plain"], 
       StyleBox["]",
        FontWeight->"Plain"]}], 
      StyleBox["[",
       FontWeight->"Plain"], 
      StyleBox[
       RowBox[{"[", "1", "]"}],
       FontWeight->"Plain"], 
      StyleBox["]",
       FontWeight->"Plain"]}], ",", 
     RowBox[{"{", 
      RowBox[{"Eg", ",", "0.1", ",", "6"}], "}"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
     RowBox[{"Frame", "\[Rule]", "True"}], ",", 
     RowBox[{"Axes", "\[Rule]", "False"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"GraphicsGrid", "[", 
  RowBox[{"{", 
   RowBox[{"{", 
    RowBox[{"fig0", ",", "fig2"}], "}"}], "}"}], "]"}]}], "Input",
 CellChangeTimes->{{3.685845319915045*^9, 3.6858453592392235`*^9}, {
   3.685845691719962*^9, 3.6858457506462607`*^9}, {3.6858458543179893`*^9, 
   3.68584586095442*^9}, 3.685846484769965*^9, {3.685846516365775*^9, 
   3.685846525727669*^9}, {3.6858491051446066`*^9, 3.6858491058780003`*^9}, {
   3.685849532231352*^9, 3.68584953565278*^9}, {3.685925071753961*^9, 
   3.6859250726228724`*^9}, {3.685928497709564*^9, 3.6859285232097063`*^9}, {
   3.685931261527886*^9, 3.685931278561246*^9}, {3.6859313389857693`*^9, 
   3.685931340300726*^9}, {3.6859313766271706`*^9, 3.6859313910680637`*^9}, 
   3.6859316139589305`*^9, {3.6859316482384634`*^9, 3.6859316611545734`*^9}, {
   3.685931736747842*^9, 3.6859317376163006`*^9}, {3.685968769460675*^9, 
   3.685968787003372*^9}, {3.6859688415146513`*^9, 3.685968870358696*^9}, {
   3.6860777436023893`*^9, 3.686077751370457*^9}, {3.686101272097626*^9, 
   3.6861012984355316`*^9}, {3.686101417847003*^9, 3.686101420902563*^9}, {
   3.6861015014741664`*^9, 3.6861015895350456`*^9}, {3.717421968224684*^9, 
   3.7174219761594243`*^9}},ExpressionUUID->"72806972-8227-4095-878e-\
246ae9aac156"],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{{{}, {}, 
        TagBox[
         {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
          Opacity[1.], LineBox[CompressedData["
1:eJwV13c8ld8fAHCryCj3utwkWZVIGSGiPgcV0bSyKgkZhcwkskNURkSKGyXf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           "]]},
         Annotation[#, "Charting`Private`Tag$13988#1"]& ], 
        TagBox[
         {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], 
          Opacity[1.], LineBox[CompressedData["
1:eJwV13k4FV8YB/CLoix3xta1RKEkRYkQ6j1RtEhEWeKXSkKFyhoVJZU1pISU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           "]]},
         Annotation[#, "Charting`Private`Tag$13988#2"]& ]}, {}, {}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{False, False},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{True, True}, {True, True}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->FrontEndValueCache[{{Automatic, 
          Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
          Charting`ScaledFrameTicks[{Identity, Identity}]}}, {{
         Automatic, {{0., 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {0.2, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {0.4, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {0.6, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {0.8, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {-0.2, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-0.15, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-0.1, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-0.05, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {0.05, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {0.1, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {0.15, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {0.25, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {0.3, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {0.35, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {0.45, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {0.5, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {0.55, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {0.65, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {0.7, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {0.75, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {0.85, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {0.9, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {0.95, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {1., 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}}}, {Automatic, {{0., 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {2., 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {4., 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {6., 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {-2., 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-1.5, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-1., 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-0.5, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {0.5, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {1., 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {1.5, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {2.5, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {3., 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {3.5, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {4.5, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {5., 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {5.5, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {6.5, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {7., 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {7.5, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {8., 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}}}}],
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{
       "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
        AbsolutePointSize[6], "ScalingFunctions" -> None, 
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& )}},
      PlotRange->{All, All},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.05], 
         Scaled[0.05]}},
      Ticks->{Automatic, Automatic}], {192., -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212}], InsetBox[
     GraphicsBox[{{{}, {}, 
        TagBox[
         {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
          Opacity[1.], LineBox[CompressedData["
1:eJwV13c8ld8fAHCryCj3utwkWZVIGSGiPgcV0bSyKgkZhcwkskNURkSKGyXf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           "]]},
         Annotation[#, "Charting`Private`Tag$88422#1"]& ]}, {}, {}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{False, False},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      DisplayFunction->Identity,
      Frame->{{True, True}, {True, True}},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->FrontEndValueCache[{{Automatic, 
          Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
          Charting`ScaledFrameTicks[{Identity, Identity}]}}, {{
         Automatic, {{0., 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {0.1, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {0.2, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {0.3, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {-0.1, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-0.08, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-0.06, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-0.04, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-0.02, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {0.02, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {0.04, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {0.06, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {0.08, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {0.12, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {0.14, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {0.16, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {0.18, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {0.22, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {0.24, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {0.26, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {0.28, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {0.32, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {0.34, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {0.36, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {0.38, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {0.4, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}}}, {Automatic, {{0., 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {2., 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {4., 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {6., 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
             AbsoluteThickness[0.1]}}, {-2., 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-1.5, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-1., 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {-0.5, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {0.5, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {1., 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {1.5, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {2.5, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {3., 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {3.5, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {4.5, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {5., 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {5.5, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {6.5, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {7., 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {7.5, 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}, {8., 
            FormBox[
             TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
             AbsoluteThickness[0.1]}}}}}],
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      ImagePadding->All,
      Method->{
       "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
        AbsolutePointSize[6], "ScalingFunctions" -> None, 
        "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& ), "CopiedValueFunction" -> ({
            (Identity[#]& )[
             Part[#, 1]], 
            (Identity[#]& )[
             Part[#, 2]]}& )}},
      PlotRange->{All, All},
      PlotRangeClipping->True,
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.05], 
         Scaled[0.05]}},
      Ticks->{Automatic, Automatic}], {576., -116.80842387373012}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212}]}, {}},
  ContentSelectable->True,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.7239162919674177`*^9, 
  3.7239163251513367`*^9},ExpressionUUID->"e52b3440-5893-48ac-82be-\
6fe27b1bd7ac"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"PVlimit1", "[", 
   RowBox[{"Ts", ",", "Tc", ",", 
    RowBox[{"1.1", "eV"}]}], "]"}], 
  StyleBox["[",
   FontWeight->"Plain"], 
  StyleBox[
   RowBox[{"[", "1", "]"}],
   FontWeight->"Plain"], 
  StyleBox["]",
   FontWeight->"Plain"]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PVlimit1", "[", 
   RowBox[{"Ts", ",", "Tc", ",", 
    RowBox[{"1.4", "eV"}]}], "]"}], 
  StyleBox["[",
   FontWeight->"Plain"], 
  StyleBox[
   RowBox[{"[", "1", "]"}],
   FontWeight->"Plain"], 
  StyleBox["]",
   FontWeight->"Plain"]}]}], "Input",
 CellChangeTimes->{{3.686100446213046*^9, 3.6861004612186947`*^9}, {
  3.6861013124449425`*^9, 3.686101361236029*^9}, {3.6861014489067698`*^9, 
  3.6861014520574055`*^9}, {3.686101626294012*^9, 3.686101640312346*^9}, {
  3.7174219861707125`*^9, 
  3.7174219884470415`*^9}},ExpressionUUID->"5d2c9118-409e-4710-8942-\
397b6efa7fae"],

Cell[BoxData["0.2917422788652997`"], "Output",
 CellChangeTimes->{
  3.72391633395912*^9},ExpressionUUID->"0e80bf17-9978-449d-8648-2bebe6de7cfb"],

Cell[BoxData["0.29616708617592663`"], "Output",
 CellChangeTimes->{
  3.723916333967127*^9},ExpressionUUID->"43a3fd48-9b33-420a-b116-\
88c3f1b85e65"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
    "save", " ", "the", " ", "numerical", " ", "result", " ", "of", " ", 
     "this", " ", "time"}], "-", 
    RowBox[{
    "comsuming", " ", "part", " ", "for", " ", "our", " ", "own", " ", 
     "code"}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"ans", "=", 
     RowBox[{"Map", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{"#", ",", 
          StyleBox[
           RowBox[{
            RowBox[{"PVlimit1", "[", 
             RowBox[{"Ts", ",", "Tc", ",", 
              RowBox[{"#", "*", "eV"}]}], "]"}], "[", 
            RowBox[{"[", "2", "]"}], "]"}],
           FontWeight->"Plain"]}], 
         StyleBox["}",
          FontWeight->"Plain"]}], 
        StyleBox["&",
         FontWeight->"Plain"]}], 
       StyleBox[",",
        FontWeight->"Plain"], 
       RowBox[{"Range", "[", 
        RowBox[{"0.01", ",", "8", ",", "0.01"}], "]"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Export", "[", 
    RowBox[{
    "\"\</Users/ryanjacobs/Documents/research misc/Solar perovskites with \
Guangfu/Estimation of PV efficiency__2017-10-19/SQ_limit_vm-part.txt\>\"", 
     ",", "ans", ",", "\"\<TSV\>\""}], "]"}], " "}]}]], "Input",
 CellChangeTimes->{{3.6859292741200485`*^9, 3.685929368137616*^9}, {
   3.6859299052174716`*^9, 3.685929931364552*^9}, {3.685930534422411*^9, 
   3.685930547532584*^9}, {3.685931303252844*^9, 3.6859313037697616`*^9}, {
   3.6860778485220985`*^9, 3.6860778514373803`*^9}, 3.6861013802168465`*^9, {
   3.6861014649985003`*^9, 3.68610146705379*^9}, {3.7174184959467807`*^9, 
   3.717418554088111*^9}, {3.717419870363593*^9, 3.7174198724029365`*^9}, 
   3.7174219925952826`*^9, 3.717458570077552*^9, {3.723916422649128*^9, 
   3.723916451861711*^9}},ExpressionUUID->"c08bf8fc-0d4d-4aca-b80d-\
7cd26eca9a1e"],

Cell[BoxData["\<\"/Users/ryanjacobs/Documents/research misc/Solar perovskites \
with Guangfu/Estimation of PV \
efficiency__2017-10-19/SQ_limit_vm-part.txt\"\>"], "Output",
 CellChangeTimes->{
  3.723916465575555*^9},ExpressionUUID->"de60e478-26a4-43fb-bfbf-\
5c831f6e8cb3"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["2. Solar cell efficiency using AM 1.5 solar \
spectrum__perfect match with wiki data with \[OpenCurlyDoubleQuote]Global \
tilt spectrum\[CloseCurlyDoubleQuote] and \[OpenCurlyDoubleQuote]273 K\
\[CloseCurlyDoubleQuote]",
 FontColor->RGBColor[0., 0.5019607843137255, 1.]]], "Subsubtitle",
 CellChangeTimes->{{3.685923090974918*^9, 3.6859231122873287`*^9}, {
  3.685924447678651*^9, 3.685924472526619*^9}, {3.6859249023724627`*^9, 
  3.685924934728939*^9}, {3.6859251255390615`*^9, 3.6859251334001017`*^9}, {
  3.6859300166830697`*^9, 3.6859300216136227`*^9}, {3.6859306087481737`*^9, 
  3.685930613314802*^9}, {3.686193912824541*^9, 3.6861939479367733`*^9}, {
  3.702483872738119*^9, 3.702483874400691*^9}, {3.717416984758868*^9, 
  3.717416985227627*^9}, {3.7174184762837934`*^9, 
  3.717418476713996*^9}},ExpressionUUID->"c9f1436f-cdcf-40dd-9314-\
4b71a38564d7"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Off", "[", 
   RowBox[{"NIntegrate", "::", "slwcon"}], "]"}], ";", 
  RowBox[{"Off", "[", 
   RowBox[{"NIntegrate", "::", "ncvb"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"h", "=", 
    RowBox[{"6.6262", "*", 
     SuperscriptBox["10", 
      RowBox[{"-", "34"}]]}]}], ";", 
   RowBox[{"c", "=", 
    RowBox[{"2.99792458", "*", 
     SuperscriptBox["10", "8"]}]}], ";", 
   RowBox[{"eV", "=", 
    RowBox[{"1.60217646", "*", 
     SuperscriptBox["10", 
      RowBox[{"-", "19"}]]}]}], ";", 
   RowBox[{"kb", "=", 
    RowBox[{"1.3806488", "*", 
     SuperscriptBox["10", 
      RowBox[{"-", "23"}]]}]}], ";", 
   RowBox[{"Tc", "=", "300"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"solar", "=", 
   RowBox[{
    RowBox[{"Import", "[", 
     RowBox[{
     "\"\</Users/ryanjacobs/Documents/research misc/Solar perovskites with \
Guangfu/Estimation of PV efficiency__2017-10-19/ASTM G173-03 Reference \
Spectra__neat.xls\>\"", ",", "\"\<XLS\>\""}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"solar", "=", 
    RowBox[{
     RowBox[{"Drop", "[", 
      RowBox[{"solar", ",", "2"}], "]"}], "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3"}], "}"}]}], "]"}], "]"}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"global", " ", "tilt", " ", "solar", " ", "spectrum", "*"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"solar", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "1"}], "]"}], "]"}], "=", 
    RowBox[{
     FractionBox[
      RowBox[{"h", " ", "c"}], 
      RowBox[{
       RowBox[{"solar", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "1"}], "]"}], "]"}], "*", 
       SuperscriptBox["10", 
        RowBox[{"-", "9"}]]}]], "/", "eV"}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"x", "-", 
    RowBox[{"axis", " ", 
     RowBox[{"unit", ":", " ", "eV"}]}]}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"solar", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "2"}], "]"}], "]"}], "=", 
    RowBox[{
     RowBox[{"solar", "[", 
      RowBox[{"[", 
       RowBox[{"All", ",", "2"}], "]"}], "]"}], "*", 
     FractionBox[
      RowBox[{"h", " ", "c", " "}], 
      RowBox[{
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          RowBox[{"solar", "[", 
           RowBox[{"[", 
            RowBox[{"All", ",", "1"}], "]"}], "]"}], "*", "eV"}], ")"}], "2"],
        "*", 
       SuperscriptBox["10", 
        RowBox[{"-", "9"}]]}]], "eV"}]}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{"y", "-", 
    RowBox[{"axis", " ", 
     RowBox[{"unit", ":", " ", 
      RowBox[{"Watt", " ", "per", " ", "area", " ", "per", " ", "eV"}]}]}]}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"funsolar", "=", 
    RowBox[{"Interpolation", "[", 
     RowBox[{"solar", ",", 
      RowBox[{"InterpolationOrder", "\[Rule]", "1"}]}], "]"}]}], ";"}], " ", 
  "\[IndentingNewLine]", "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Suntot", "=", 
    RowBox[{"NIntegrate", "[", 
     RowBox[{
      RowBox[{"funsolar", "[", "x", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "0", ",", "4.5"}], "}"}]}], "]"}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"use", " ", "global", " ", "tilt", " ", "solar", " ", "spectrum"}],
    "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"PVlimit3", "[", 
    RowBox[{"Tc_", ",", "Eg_"}], "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"Qs", ",", "zop", ",", "zm", ",", "u", ",", "v", ",", "m"}], 
      "}"}], ",", "\[IndentingNewLine]", 
     "                                                     ", 
     RowBox[{
      RowBox[{"Qs", "=", 
       RowBox[{"NIntegrate", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"funsolar", "[", "x", "]"}], "*", 
          FractionBox["1", 
           RowBox[{"x", " ", "eV"}]]}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", 
           RowBox[{"Eg", "/", "eV"}], ",", "4.5"}], "}"}]}], "]"}]}], ";", 
      " ", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      "                                                     ", 
      RowBox[{"zop", "=", 
       RowBox[{"Log", "[", 
        RowBox[{
         FractionBox["1", "2"], 
         FractionBox["Qs", 
          RowBox[{
           FractionBox[
            RowBox[{"2", "\[Pi]", " "}], 
            SuperscriptBox["c", "2"]], "*", 
           RowBox[{"NIntegrate", "[", 
            RowBox[{
             FractionBox[
              SuperscriptBox["v", "2"], 
              RowBox[{
               SuperscriptBox["\[ExponentialE]", 
                FractionBox[
                 RowBox[{"h", " ", "v"}], 
                 RowBox[{"kb", " ", "Tc"}]]], "-", "1"}]], ",", 
             RowBox[{"{", 
              RowBox[{"v", ",", 
               FractionBox["Eg", "h"], ",", 
               SuperscriptBox["10", "15"]}], "}"}]}], "]"}]}]]}], "]"}]}], 
      ";", " ", 
      RowBox[{"(*", 
       RowBox[{
        RowBox[{"2", " ", "if", " ", "from", " ", "2"}], "-", 
        RowBox[{
        "side", " ", "emmision", " ", "from", " ", "solar", " ", "cell"}]}], 
       "*)"}], "\[IndentingNewLine]", 
      "                                                     ", 
      RowBox[{"zm", "=", 
       RowBox[{
        RowBox[{"ProductLog", "[", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{"1", "+", "zop"}]], "]"}], "-", "1"}]}], ";", 
      "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      "                                                     ", 
      RowBox[{"u", "=", 
       RowBox[{"Qs", "*", 
        RowBox[{"Eg", "/", "Suntot"}]}]}], ";", " ", 
      RowBox[{"(*", 
       RowBox[{"spectral", " ", "mismatch", " ", "factor"}], "*)"}], 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      "                                                     ", 
      RowBox[{"v", "=", 
       RowBox[{
        FractionBox[
         RowBox[{"kb", " ", "Tc"}], "Eg"], "zop"}]}], ";", 
      "\[IndentingNewLine]", 
      "                                                     ", 
      RowBox[{"m", "=", 
       RowBox[{
        FractionBox[
         SuperscriptBox["zm", "2"], 
         RowBox[{"1", "+", "zm", "-", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{"-", "zm"}]]}]], "/", 
        RowBox[{"(", 
         RowBox[{"zm", "+", 
          RowBox[{"Log", "[", 
           RowBox[{"1", "+", "zm"}], "]"}]}], ")"}]}]}], ";", " ", 
      RowBox[{"(*", 
       RowBox[{"impedance", " ", "matching", " ", "factor"}], "*)"}], 
      "\[IndentingNewLine]", "\[IndentingNewLine]", 
      "                                                     ", 
      RowBox[{"u", "*", "v", "*", "m"}]}]}], "\[IndentingNewLine]", 
    "                                                     ", "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.685846573719669*^9, 3.68584659931281*^9}, {
   3.685848440898419*^9, 3.685848443744814*^9}, {3.6858485131604176`*^9, 
   3.6858485150979476`*^9}, 3.685848555713873*^9, {3.6858485894120903`*^9, 
   3.6858487476069145`*^9}, {3.685848831480568*^9, 3.68584889078393*^9}, 
   3.6858490426187997`*^9, {3.6858492751089354`*^9, 3.6858492800791016`*^9}, 
   3.685924432763629*^9, 3.6859249822176332`*^9, {3.68592529444184*^9, 
   3.6859252972431946`*^9}, {3.6859253828828583`*^9, 
   3.6859254300085883`*^9}, {3.685925518602713*^9, 3.685925568866953*^9}, {
   3.685925690978526*^9, 3.685925695319916*^9}, 3.6859257855570445`*^9, {
   3.6859258171199894`*^9, 3.685925849469246*^9}, {3.6859259320312705`*^9, 
   3.6859259382940025`*^9}, {3.685926590742663*^9, 3.6859266190341005`*^9}, {
   3.6859267928568025`*^9, 3.6859267966246643`*^9}, {3.685926853934599*^9, 
   3.685926854549651*^9}, {3.6859270598338137`*^9, 3.6859270602802944`*^9}, {
   3.685927277696269*^9, 3.68592728781234*^9}, {3.6859275013215094`*^9, 
   3.685927619711701*^9}, {3.6859276565019236`*^9, 3.6859276638035574`*^9}, {
   3.6859285510622973`*^9, 3.6859285524130993`*^9}, {3.685968433296256*^9, 
   3.6859684410400915`*^9}, 3.68596996773964*^9, {3.685970006523214*^9, 
   3.6859700364974723`*^9}, {3.6859701290827093`*^9, 3.685970140974*^9}, {
   3.6859702502697906`*^9, 3.6859702506918077`*^9}, {3.6859703272377453`*^9, 
   3.6859704140131893`*^9}, {3.685974992918239*^9, 3.6859749961183553`*^9}, {
   3.685975173580391*^9, 3.685975200511608*^9}, {3.68607545087689*^9, 
   3.6860754663775454`*^9}, {3.6860755042351017`*^9, 3.686075524715336*^9}, {
   3.686077123859256*^9, 3.686077128408001*^9}, 3.686077339193065*^9, {
   3.6860773878911057`*^9, 3.6860774208708525`*^9}, {3.6860775447229276`*^9, 
   3.686077596274011*^9}, {3.6860783934737997`*^9, 3.6860783954047003`*^9}, 
   3.6860784468617535`*^9, {3.6860986108688707`*^9, 3.686098613455679*^9}, {
   3.686098799849723*^9, 3.68609884667379*^9}, {3.686098970048646*^9, 
   3.686099009736675*^9}, {3.686099133847046*^9, 3.686099141874243*^9}, {
   3.6860992019005833`*^9, 3.6860992583138447`*^9}, {3.686099292789621*^9, 
   3.686099412086218*^9}, {3.686102288377672*^9, 3.6861023026146684`*^9}, {
   3.6861939738093576`*^9, 3.686193988503187*^9}, {3.6861941675911493`*^9, 
   3.6861941695073423`*^9}, {3.7024751441674843`*^9, 3.702475155939623*^9}, {
   3.7024762336850395`*^9, 3.702476257838845*^9}, {3.7024836214359922`*^9, 
   3.7024836351166615`*^9}, {3.702493303179511*^9, 3.7024933572365093`*^9}, {
   3.7174171095074153`*^9, 3.7174171497703075`*^9}, {3.717421424041909*^9, 
   3.717421441826576*^9}, {3.7174214766448946`*^9, 3.717421478481439*^9}, {
   3.717421565518525*^9, 3.717421565956031*^9}, {3.717422016384097*^9, 
   3.717422032005375*^9}, 3.7174221192081594`*^9, {3.7174223295964885`*^9, 
   3.7174223305730853`*^9}, {3.717457558222806*^9, 3.7174575794812016`*^9}, 
   3.7239167557464437`*^9},ExpressionUUID->"44787964-f47e-4727-8cfb-\
667c0a939299"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fig4", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"PVlimit3", "[", 
     RowBox[{"273", ",", 
      RowBox[{"Eg", "*", "eV"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"Eg", ",", "0.1", ",", "4.5"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
    RowBox[{"Frame", "\[Rule]", "True"}], ",", 
    RowBox[{"Axes", "\[Rule]", "False"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6861933652822657`*^9, 3.6861933670134153`*^9}, 
   3.717422039898182*^9},ExpressionUUID->"56959b2c-253c-4f3e-8f3b-\
3409278daa7c"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
      1.], LineBox[CompressedData["
1:eJwVl3k8lV8TwJF9vSoqIVmKZCt7unOylPWXkF0kyRYlW6RQUqKIkl2J7ApJ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       "]], LineBox[CompressedData["
1:eJwBcQGO/iFib1JlAgAAABYAAAACAAAAqH7Q9G6gEUD+rBFRXlm9umQq1aer
oRFAtJ5aJOeNFbsQAZuHN6MRQEnQ054WuyS7wFuyBmepEUDllNYDu6AuuyAR
4QTGtRFAV3HlyPENMLvgez4BhM4RQH2yXsLGqiy7jFIE4Q/QEUCD/sEYzzQs
uzgpysCb0RFAV5Eq0ny3K7uQ1lWAs9QRQCINNq/Rpiq7QDFt/+LaEUBE6jhi
py0ou6Dmm/1B5xFA2jEt86feIbtMvWHdzegRQMVDiXRh9CC7+JMnvVnqEUB+
fkLL9wIgu1BBs3xx7RFArY+PQagVHLsAnMr7oPMRQKuvZgldjBO7rHKQ2yz1
EUDcLcRCY0cRu1hJVru49hFAzmkRSpnpDbuw9uF60PkRQDb7iJcwTwS7XM2n
Wlz7EUCir/ZIa7b+ugikbTro/BFAxpG9+rad9Lq0ejMadP4RQMH01WidsuS6
YFH5+f//EUC0pb3TNXICulFWsoo=
       "]]},
     Annotation[#, "Charting`Private`Tag$306987#1"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0.10000008979591837`, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->FrontEndValueCache[{{Automatic, 
      Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
      Charting`ScaledFrameTicks[{Identity, Identity}]}}, {{Automatic, {{0., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {0.1, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {0.2, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {0.3, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {-0.1, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-0.08, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-0.06, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-0.04, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-0.02, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.02, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.04, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.06, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.08, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.12, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.14, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.16, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.18, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.22, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.24, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.26, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.28, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.32, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.34, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.36, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.38, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.4, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}}}, {Automatic, {{1., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {2., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {3., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {4., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {0., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.2, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.4, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.6, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.8, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {1.2, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {1.4, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {1.6, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {1.8, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {2.2, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {2.4, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {2.6, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {2.8, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {3.2, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {3.4, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {3.6, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {3.8, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {4.2, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {4.4, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {4.6, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {4.8, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {5., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}}}}],
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.7239171190174913`*^9},ExpressionUUID->"46fc3b67-77f5-4438-9591-\
9cf29cf8dfeb"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"wiki", "=", 
   RowBox[{"Import", "[", 
    RowBox[{
    "\"\</Users/ryanjacobs/Documents/research misc/Solar perovskites with \
Guangfu/Estimation of PV \
efficiency__2017-10-19/Shockley-Queisser-FullCurve__wiki.txt\>\"", ",", 
     "\"\<TSV\>\""}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Show", "[", 
  RowBox[{"fig4", ",", 
   RowBox[{"ListPlot", "[", "wiki", "]"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0", ",", "4"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0.35"}], "}"}]}], "}"}]}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.6859738545019045`*^9, 3.6859738621767116`*^9}, 
   3.723916818298275*^9},ExpressionUUID->"600f6439-ba37-45d2-8ac1-\
738879fafefd"],

Cell[BoxData[
 GraphicsBox[{{{{}, {}, 
     TagBox[
      {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], 
       Opacity[1.], LineBox[CompressedData["
1:eJwVl3k8lV8TwJF9vSoqIVmKZCt7unOylPWXkF0kyRYlW6RQUqKIkl2J7ApJ
2XdZ773uRaSQfb32vd7n/ev5fD8z5zxzZs7MmTlq72F0nY6GhqZrDw3N/7/v
zmkdToz/Cm4f5Q2++N2oPs7x7Rbb0leo1zr0ejXNsTqvT7opQPcbdJ69f+VF
/fXqLx4Hb1tvf4MTa0VMMyvXqtuTZ5oEbCqgQck2Qo7VrtrI2Y7/+ecK0MR/
umcofKW6V55y+y9HJTwN9be9R7aqHmmr4v9dVQlkQ72+s35m1eub0Z5pQtXA
e5L6VXhLr/peI2ML7m41BHfuLy+XvFBNFx0gEEyshncnpU/ICqlXM8aeGpU9
VwNDbzw04uROVnNL8r/gXqoBEZdVNwURBMcsFkZJxnXAS0O46yhwFSarsrnY
gupg0zVBOmjcHnJFHVQ18upg7r8zkYEfHcA9XPB6QF8d1Jz7lL2yzxFkqX0v
iunrgf3cOL15/g1YvhzzbUa2HroCjQtODDhDabnBmIhNPcjokbimRNzgTFid
auzneqjRXBzQprkFf2fvXW8frgdZmWuRy0y3ocZIKYqeswEuSd3bd5XNE84L
5o15OTZA569+VSElLzD8/Crq8oFGuH47gIY3yw/2HjYsj9RohEAz4dw+VX+g
BLGON3o0guKpvafVDgaApf6DM4otjRDZbPKSqzMQrv9xGue92wQ6eNeKh57B
4M+tptbX3wzvIlXePJl6DJVBU3EtrC1AEmxDr/PCgIb6erlMtQUI4fGnlROf
QFjnYk58Qgv43vyPNsQuHGKffThkZfkdtAdy7Ix/R0IBw771wR+tEPyWae+3
Oy9h0avGqJOlDSZdLDX1pl+C/OjNgiqVNvgi6H/qhHoM+BkfZi10bgM6/cbD
uN4YKK9ruZ4a3wbjLld7Dl2KhZYH98l2Fu1QQEBTz4New/Dm1Kc/fR0QeuyV
jEpDAog6x3GQmTtB4pN816JNIjj1aTo3KHfCiKBuUdT3RJgvTRXKeNMJ2qaq
y8sLSbB15/ILR/MuOBpC9eTiTAVWX7vSFVcC9OJIvo2zbyFPWml09iEBREqP
qt47/w4Mxjn2jiUSYO51uZbm23cwnzwKg8UEqPhx5KX3zjuIulx+k9JGgKYv
dYXPTqbDKY6XiR1/CKBbKLryyCUdyA1O3xu3CXBs/mzNaGo6+NyD9cp9ROA+
+G/XbTUdDsjzipVKEsHsoNbePZzvoWxm1qhAgwiqRVpjB++8B8v0+qBMKyJU
bLbJSCS+hx3LhIKUO0QwdSjJaJbJgJS9t3++fkYEX+YlyZbUDECtF1hfpBNh
pWaBktGeAcPBgsph5UQIOzvtk6KcCSEqq9cfdBNBb18sT4hfJogutsX4zhCB
9mnQcq7HB9h/aNiz/2EvKHCmbvLc/Qy4Y4wGojSDcJHbVGVLtwboYTJi8cAg
COxh/u+Mfw1smLW2V8kMwi/XTYfIuBqYvZXHHnFhEHL29TfdyK+B4afP9S1s
B2F8S0OsI6cGet7dijjmOwh2k/Z/GbproLXcqH35+SAMiF59rT9dA1Vkefba
zEHg7M155MhTC0VzvPrPqwZhp60nMexILZh8Pq63ce8XVFYluj6ZrYU4TR2d
9s3fkPi1dqUsvB5eyDUJf7s7DE5SlOhKvSZ4wh5+m/JoGKr3/z7Xot0EIRMG
NdQXw7DC1TMtatkEAXXcXOyJw0D/6hKPTmQTeCVTbI5nDsOux1cNseAmuOkX
n6f+aRjuJSwmpX1qAkdjm22bimEwrcrJ/P22CWylj+rebR6GhHUXg6W1JjBn
GXsTSxoGnTP5wbjxJrg0mjVRODgMJi9+Feb+bALdajfFtslhOD1O6aVXagbN
BNnQ8eVheKg54MK40wRnvVe6af8Ng5DPYOxp1mZQNCwTFmAdAe2WfMPnx5tB
VvLebWWeEXhb9X3PA5VmkGBENcZCI8AvKWfacrsZhIf3cHlIjgD3oyKlA5i8
JOrctsjgCIhHzx5J+68F+hcquiPRKMQ0cCU1ZrbC6chK6Tj9UXCjOb/7MqEV
Ik5UPU0zH4VfuUTRosJWGG+uGs12GIXtPBvepPZWgOvVUHxrFL5kKLV7TbXC
G7qahIp7o9D+qpZ5krkNllJrVhufjMLAZixtslIb6J2tNeyKHYXUFkNG0G6D
9/21uX1po+BsP200f6MNPBqbHorQjkFhP3uxMX87tNg3/zrJMQYt5Ycli+Xa
QZimRUXx0BisfGgs0HJoh4DkllgQG4OjmXbjZx+3A1n1+4K23BisH9WV94xq
B+m+77pGZ8dglP2KknBlO4R5t2ZY6YxBeoBZj0tFOwztbaO5fnkMGHcShC4Q
20H1Y5uV+9UxMOPYdlBqaYcYg/ZS35tjcM74ploTWwfMTrdzB98dg3eWCnbu
6h1w/kmHW3joGAgFVZKV9DsgVayzOSZ6DBrrmw1SLnfARl2ncHLyGMiPBzDd
se8AI7uuwMzsMRhwlomeCuuA3N2uvsLPY3DQ9YDXYHkH0CcSTn+tHYNAOkNv
77IOsFEmPq/rGAN3wTgVKmMnlFKIU20/sPN8Gq+43NQBuDskTcoYZg/HZQY/
gU5wxnWn/locAzJrSo+eeCfU5XdvTeyOQRyPfYwjdAK/HvnyIss4MJunBGsZ
doL3JPnjFs84FL+0ntjn3AmdoRQ2euFxuCSyG17i0QniIj2OHNLj0OytvphW
3AnBNT21vKrjEO5lcHaprBP6bXr5hc6Pg9C4zoOjzZ0gv93rK2E0DmHnT6zl
TndC5Js+0qkr47DUz1OvvdQJ4wo/pNRcxsGjnxj0bqYTUPePJ1o+40CedN8d
5OyC+Fv9f/4LGQeX2PddON4uWOIYwJs/Hwe/jRsXOE90gX7uQPzVBMyefSOt
/Se7IEP754pL5jiUWQVcXRHvgr9jPy96FY0D42R7f+b5LjB/OJgTWDUOiQID
vt7PuuCT0C+GsNZxGDbHXRDEmLXql11UzzgQo3ij1p26wMHqd3n8yDg8PGIq
9uVmF1Ru/OZNnx+HRrRhMxLVBbyvh27nbY2D+Vf/LK/YLvhOGD5evXcCWA5K
uZ792gXC7iMhLYIToM5ixZ5U2AX32P4MEk9MgLIM/7pKaxdQsv4oDyhOQFnx
2/2fBrpA+vxozKj6BJzjiXm0+a8LjPYMVHz+bwIUI+Reqf3pAu8a4thjywnI
HJNPFGMgwJvAFk5zxwlQU/O0ItNg745qtZKE5wSclbIofstMgN/rn+22AieA
ZrHtxXMBAtB9znva9nQCfjubXL3HhL07nulFSa8m4EDTTsXLvQTQkUkYuPl2
Amwqt48vcxPAbTaKHvIn4NqftokuLgJEZYdJ4b5OgOjh/0YzWQlQ7HjfdLhh
AnZfWLa+Pk6AHhHvB0WECWhzIT/QkiLA1pBr1sOfEzDpuJFCVSCAQIo90WRy
AvayXT2WhwiArCy2xFYmQOORdpjpPgI4HDQUWf83Ae7TVRGKFwmQOF1exFI5
Ce6VzBFtMQSo+lA00N8yCRwmNzWj3xJgxCGbPo88CQ9TXrf/yScAg3CaVODQ
JOx78z7xdxYBxH+/Nv1vdhJW9ALSEz4QQD8p8sGRjUnYb5L3wymNAB4Wj7Ko
e6ag6E7f6apKArzkDSDWck3BDeXukzoJBCjtvr318vAUdODzLH/lEKA/yknE
4fgU0B4ccQzH3vldA1t9hdNTMNSh9+04iQBCbKbejDAF0Q0mUj41BNBs0U/p
1Z2Cdq/0322dBHAK1WjOMp2CaQE5JS3sf8/UVal37bH9y3UO+WJ9QsE/2UN6
7lOwj5c+nr+eAKSK4+r8/lPwqW99qXiIAGt3BV3nQqfg/KDPn16sjzikxBNb
FT0Flbs/BK9NEkBtha3yRfIU1PUu35z5TQC7T3TjdtlTICMbv705TICH7puc
pz5PwaPxWyrFCwTIlKQq7amdgn6iqWgbKxFaJ8ftyO1TEMr0TdWahQhzGYNP
M/qmwDvjqoozlQC4a+Qin9Ep+LNqcvTQFAHkhdoGLlCnQCXWYf/hVQKYDdbS
H9qZggkJV7NDvETwTyiTmmaahiNaxWPGNERIMSs0Ld83DYdr5W/s0BKhdn/m
g4gj0/DViK1zgosIo8SkLBvJaUgo3qpwxJj5RQxRWmka+HoC9JL2EyGHzyZb
Xn0aTC8c7h88SwSDzGPBqgbTcHzxrdjhA0SgylHNkfk0aMwY1koKEuFl5VfZ
89emIcYsOyb0GBHkdR4y67tPw9AZGWNOWSL0kvWHLt2dhkOTdxUHpTB77XjL
zB5Ng3M6cy6vIhH4Z3+/sHkxDdSb+0ZOKxChyjf7xrWEaTBSmuHysCTC1T13
wDljGkQ9tbi6rhOB/oXaAY+P0/D7flHFLUSETD7GBa/yaTDrZKr9qU8E7cyu
Jv+mafgs/qzoljURZuTiU4KI08DjMLxobECE55X2Po9/TkPRMftLv24QQVbn
5H8RE9PAqml2+ZAHEUjkVbGXS9OwL+ZePT3W53nbVe/G7U6DckCa1fYrIhyc
fUJJZp6BG9+8v71MJMI3X6P89H0zgPdXum/xmAjWe/hDswVnoIYxY/5sHBH+
PR+zLpSYAXuZ1meS2UR4x1co/1l+BkYtlj8n5RJBM9OPvRxmgJ5eN8injgjj
cuqjNbozML/xWL69mAhPK9kqmi7PwLcQ7Uq9SiKc1KHEtNvNQMwdaiOORIRO
cooryXUGBGYE6jJ7iXDLzkmjz2cGDG1fXNeaIMK+WbnDv4JnYPsZeefLMBFK
fbeX/kTMwKMNogHtMhHM9zS2TsXNwLqympHvGhG2nj9/t/BuBtq4jkfO8pMg
mc/cfzV/Bv74rCX8x0IClHnUaLtsBq7c/qheu5cEI3IzErQNMzBn+czdaR8J
HlWW0DJ1zUDQB6ZIV0kSHNe5/4O9fwYk6vZyK8uSoJV84dPesRk4H6+THQMk
cLPjfnqQivlvLUCeTosEnLP9doLbM7BhEA6FDiT45PteWZRxFlbmOMo87Uhg
sscdd4J7FoQSitQS7pFg7bnSpAz/LNSctLyQdocEb/hoaxSOz8K3XOdyyWAS
nMlsjTtzahZ226NWNJ6S4JdcrMe5s7OwzKCqcz+VBEGVNhcuaM8CvbRRj2kx
CYR1jh8xMJ4Fmx2XoK/pJGgkU9eMrsxCv6VQTk4uCZzsvnWaO8/C6ZPO309j
+qyzDzOveM1CkuybdfY6EuT5Gtx3eDALNE9Dqq52kuDingOmLuGzEHPbWVp8
iARLz4ekbr2aBduSl3Of+kkQy5fD4JM2CwE0xFPGmFwx885gQO4sKF9WscGv
kuCH3NnPwaWzIHNF4UMUfTfcq2SMDKudhUP2O1F8rN0gqENwiGyfBXN1Ca2M
/d1QQ45Xi+mdBTe3mN1djm6wt7u2P35kFq5+kDprKNkNH3zX6t9vzAJ3P8Hp
D74bchp3PryhnwPWtJ+OD/W6IW/fnogI3Bzs6Rw8d9ioGwqvstwK4p+D3lfj
zsOXu6GokMvES3wOOFmaoiUdu6Fkl0fZSX4OwvptUp7f7YYvevz81mgOxFJ7
ejYzuuFbvDCNof4cCDDG7q9N7IaKCfFRDfM5MIs3s1HD5FUKMi1KDnNwkz9L
dCa1G2ofKuRJ3pqDrf4016qCbmggnok6cm8OxDuvdHKWdUPTEXWvfU/m4BNv
xT/lmm4gmlnR//kyB0mZpSXW/d1Azrg62VM/B2/AtbVuuBt6lm+0t3bNQcfe
F3/w1G74cc79Y9XAHKxKyOvun+6Gny+8Yosm5mCclbuqbb0bfg36+2UuzwGp
aVnk30Y3DEsGWyf8mwOW/g3ahX/dMHo3DD1nmwfFi7Et1znJWH8eKRpyYB5e
GTkW3+UiwyRPLLOPyDwUBMmZq2LymWsJs84y8+BAySgr20+G+U9pBJsz83A4
98OB/ENkoP7LLLl0YR4sjBeaTE+SYdkg/42W8TyEHpWgO4/xWmLxPRXbeYi6
dcJ3U4oMG1Nf7aRc58GpgC7fQY4M20o1mkd95yFNrph5VoQMf0ObxHkezkMd
3WoytwwZaMjt7Cwv5mG/y017d0x/j3A3dSdhHgTKBjStTpOB8dYPMjVzHt6U
kBVVVcjAXPW7bLRoHj7+fq+TrEYGNvbxpL4qjP0vjoUeJAOn5WxQe+s8jFzQ
aqk/SwZc1pJDTc88EK7TfFw+R4a9axvaJSPzIHI4pDsBk/No/juZNT8PyU9j
9AKADAdfMnAnbc3D8d6dwhfY/nxDbKsvGBdgn3lIiIkWGQSk9/54uHcBGNRZ
mNl1ySB072Clr+AC3Por1z0lSwbhVsG3ricWYPhVsOs1bTKIHRQLtVVcAIs/
ArfTdMgg7ijpbKy+ACpD74qomPxEiZzBhf8WYGE7okpJjwxSdMpyZywXoHuh
ZWbzMhlkDfE8Mo4LYCNPs4fVkgynUjQ3hT0XQJA/2pTNmAwKs7qDvPcX4M3J
aN+lK2RQVr1Uyxq+AHlReKrQdTKoPjHL+PtqAZizhF4NO5JBrcfm6dLbBbhp
vfNk1ZYMIOpwczx/ARa/Sgxy3SCDuqfLpf6vCxB3JMSeaE8GzZpbCp2NCyBa
YfJeLpAMFzh9D9URF2DaUyOjEluvax24+3lwATrZEvdOuZBBP+fhcPYUtn9U
wDKtJxkubjxtTF5dgHSarP4ZMzI4hcudvEZDBZG/+795eJMh+2CK9zoDFab1
/b3msfXTmazVz9iocIZ9f3qrFRkkFXyZhbip8Puio9lfzB63+j+XSnipQH0W
vxDhToa8S4aJ2vxUaI6s+XvoKRnmfleM/jxKBZtrHSElbmSQdpeQvn2cCurV
eu06rmTw2HnlyyBFhabiulgDPzJ8DKerjT+Fcd12vcIdMiwe9GCVVqaCsNdB
jUls/akPA8Z1Z6kwXtKQN+FFhjsK2smmGlSwUzmnpOVPhpL6kvFpbSq8C78R
0fGIDCuXjso++I8KvX7rFWmhWHyGIu/uM6GCYdDP0PsY+7hv1X2wwPb79wnS
4slQuuPIrmZLhds+s3TuQWRYD+++THCgQokYj6XaSyyeh1Cqgwvmn+5hlSdP
yHD3Q97khgcVlB/0eh54TIZvCodORXpTISPen+iMybfrQwOOBlDhCPd6VBvm
DzWjpYbPQVSgKTD4mYPJA4eucOo+poKYTAmIhJOhyr3N7NczKiguUerKMP1/
O0pvPaOpYP3R6u5X7P/o2ftpxjhsPe2LsR8RZAg+xC2fmEQFqe6rsaUY130I
DJR5R4V+Nm5TvtdkoFOcbqr/QIXjDwUW5ePIoNFgijPPp0KA7m3/BYwfGdVb
zBZRweDyhKVzAhkahmTSg8qo4Kr6g3YnkQwMHkmz+6uosFdDuaQmhQznd5kV
s+upoBNtK3osiQxhz7wfnP1OBcrH1jBrbH3LoZEWYicV4lSVWwpTycCS9d9e
RzIVPiTy/Gh8h91PxXKrrR9U+ELoNKTB7HvWcDzj+W+Mr9cc6EknQ7tR7Lzw
GBUaCgQO/vpIBvZhGuUv01TADVufvphFBgOPm8F6VCpssd9kKMPseb77o/X3
KhWMApa2uErI0Pns/H6vbSqkd0oE6hSSgYuv2IaZdhF8P//8kPqJDIZZRz4k
MS5CLX7CNryIDNGKEVRZ9kWY+5sU8KaCDKSGDZVG7kU4oFYTzfGZDPuMrz+0
OLAIhcIPU41qyWAyTGyf418EhY+EjK0qMrzywPOGCC9Cqvy9osF6MvTs5tjy
ii9CQ9jTjh/NZDDje7SEP70Irxi+CC8TyfAmi3qmW3kR3vmsdR/pJUOfok3o
DfwiVtdCHpN+ksHSWPFglM4iLMgbP/KZJEPi8LurohcX4R/7plz7Ahl+enDl
lpkswnZQ6YD3Glb//gas6Fsuwt2pZv/5HTJciZg8O2y7CF+WvPYV01Lg0QlD
d4vri0D7+m6cFhMFclq+pBBdFkFiPdJ/hI0CBMcjXTq3FuGBS+c/Ko4Ca/Rh
/2q9F0HssGkVPS8F+NPnZVQDFqFt+HZxtQAF1M+Z2hUFLYKVTemLITEKOP2u
jDrxeBFYrj6qYzpJgchAsdp3zxbhjO7T8mZZChQdjlzki14E8U3KzQklCvR9
XTka83oRcMc6ueWAAqJr9SEP3y5C5tKNfVEGFKhwt9d0+LIIR6Q1e3acKDDC
3ur1s2IRPh7K0+vwoABzrlyGSd0iyK9LGgj4UEBaJ57S3rwIx9T9FNPuUcBk
goZRqwOzJ3K1KzuYAv6hToqVJMw/vFl3+B9TIE2E4KjQtwgZurO14U8p0FSr
FJc/uAifs14WfougwIxtarPYHywe80GJH59TAPeXcSN5chE06691iUVTQDHJ
XZx3fhEE+xY8Nl5SwFq1x/z58iKMy2hpCbyiQEjf2aeMm4vQr+uzEf6aAlk+
GV/v/10E4W73efwbCnTu55he27MEaWMspV3xFFgp8uLzYFmCIe4LOscTKcB3
6afuBOcSjDfFVVkkUQAtaATY7l8Cy+un5rWSKeAYmZvbe2gJ/Fzf2hIxjpDc
9/PikSXAf1MZIqRg/v7uz94iugQ/B4XvRqdi/r4xooZOLIE/T4uadhoF/jLo
3iyTWQIh6aHDGhiLvv+ULKuwBFpuPnyhGOuoH+rMUl2CSj9KdCzG7kNBf4XQ
Eja/qTolYRx7f1I6XmsJcqIsFTYw/sZvaMuttwQjeYKuOxgPffvy4qnhEux8
nfTdxZjR4kgNrekSqD16EPAL45Prj6l3rZaAbn6ZcRRjo1fzQkt2SzBctKJc
i7HfadNLLo5LYDxmUR+EcQqxMnjEdQlM+4Kzz2Hc4CFWZHl7CVByafcMdj5c
3spevXtLoCw+v2KOsaKutUZ98BI82mlsZcXYerL+zpmwJeAp0rLNxPwT8ljy
fXHEEgQZtu1xwzhLNIYs+RLbn+fRlhHGnXVb9O/jlsDl7zzXOObfFTt7Bf7k
JSh5hNO6hzHfv+/XY98tAa346pn1/8cnWe41e9YSLH9XN76BseOZ+KZH+UsQ
Y1t/ahyLZ8QPmvWdoiU4c+7f7WsYF/k6Hfcuw84n9n6LkkCBXh6C2Vwl5n+S
3TdbjE/ymD7/WY/553AITw52P0L2/2xo+74E97r6fH5g90d636RcDmUJjkje
/yoVR4HHOBr2G3NYfFSfJNyNocBPrsfqpstLkOlTuByI3c9TXOx3tTaXgFXZ
VPs9dn9/cRwcF2FYhnYhgnT4C8xfbLI1Q/zL0OPlVvUvHLOXtXStS3gZwj/l
X/2B5ccIi5pUtfgyXD92PSjxCQWeM2snJMsvQ76E5IkTWD6NM9h5Wepj6w/N
MU4FUeA1TZQ4OWAZMg71Xid4U2D2H49tffAy/FNJGjnnhdWPf4mvisKWwVM2
LK7MkwLzux/oomOWIUlw++Z9LL/Pb1f/NMhdhu1zczrtWP6vrS5ENfcvw1md
RXplKwror3o3lw4tw8mEpYcWFhR4t7K9mzG+DF8YvbrumlHgv2Um10dLy2Bs
FMsYaEyB90uRb+9sLMNF924B/0sU2Frc12f/dxlEptP/xV2kQCb1iNY51hWw
OmjYUqxHgZ2FjABZ3AqcsxKSJ+tg93NBsugI7woc75aUoNfG7sv8p0lO/hUg
8zxIkzuP5dOc0pG/R1eA11BmwFETqz9zlZfnjq8AdeJnCU4Dq7ezGhE/pVYg
csc7O/McBWhmv9e1nV4Bf8ue5CxEgcszFze/qayAZlL0UWusHk5fgjBNWAH5
zPqIOTwFgsqkeTo1V6Cj5w5rPsa8RwTTzXRX4IZSTv59jHNDOeSGL2I87vJB
FWM0u1PlcnkF2ALoQv8v7zGa1V+xXIH3VM2eFozdvg70B9qtQDLHvyJh7H+0
Qm1OTI4rkL8ULS6A8evH39aiXFdACp8fcxbTPzmX/Yjv9gqUn1LNFjlLgTrj
+L3vfVaAbrDN+r0aBcy+PUmTurcCjVIE4b4zWLyF/KS/BK9AyXcz4wyMQ8Ju
VKCwFUig72vuxfQPzpvqtkasgGuu0RdJbP98k/N9xi9XYHJhkzUZ+796uYLj
YNwK/FL4rmyC+avvqNiKY/IK9EZxqvWrY/Xoyf4Q6rsVcI8nT/Vi/t6zsAfn
n4XFozSvvRuLx5vLy8l7ClbgFWPHqi4WP+mKEcnI4hX4OxXiPI3Ft0GY9JX3
6wqccBkeu/EfBSye1l5Iq1oB0WnZHF0j7D4ufKRINKxAxaGjzdWXsffTNO1a
8XcsPmbBHt3mFCgUefCgibwC3MZ5LCNXKMBQpfZldnoFMsxOXZl2pUCC6Ekt
H+oKeHrvTL7D7rPss8Pd/1ZXwDClCsd9hwJW5lvze2lX4bZQesaOPwWoVVP3
khhXoVbOVm34PpbPYj9Yj7GvAjOtMm9LCPb+RrS8KeRehbOR7NPvQinwaenL
MZUDq3DYLSrHF8vH8xYfSur4VwEXzCgSg+Xvz+rX6vrCGEv69ytEUsDz2GMC
5fgq8LeX3snD8p8p0vuKrdQq1h/ZmG5h71PSssPs5KlVyIyZZHHA6tcpSxN/
T+VV4Pxj/U3iLQVaajSYd86ugmr+33XTTArYHD/9OlRjFZQFFBt0cimwFCks
yqWzCmP/aXq5FFLgyQp30Zv/VsGP801BbhEFBK1okbDJKrAI31mX/EyB4lpq
R67FKnDFPJig/0IBbfEhKwXbVZAxZJsYxfjX866pKodVqNg+VtKPsddqla+2
yyq0sR9wCSylAIt1AQPJYxUelg5bf8L2S6lLjrHyXgVWvj7P4RIKyEtEHh3z
XwVj5mcqy8UUsF1zPbsRugouFY3RLJg9K9ZWbcHPVoHkfYD05SMFwut1Ldii
V8Ek/MekB2a/0AnVidjXq9DXdp71cgEFPkdJeAsmYf7HPU4XwtjfXInlyLtV
aN/fyjORj+WbkFbykaxV8DJhnqjBmHHSSE6oYBVucY9Ur2HcXmjXKFSC/T+w
41oPxi993S2OflsF0y2/emZsPzO4N3e0ZhV0T34njWNyfqbwYOGmVVBfHRvy
x3ikM45HpH0V/nuA7rhgnPU6I1uEtAp7uaXidDC+eaX4rGjfKhzZqT9KzsPi
d6yWKPoL81/chGonxhtzndfFRlfh8uGnuzYYV33+uSk2vQqObpE25TkUeBg4
HXmMugpR2l3+mVlYPLQ2jh5fWwUxPnxQBxZvTg7G0uM7q/AkN5hJB2MyeZ+u
ON0aCNx58t8pjOOTjv4SZ14DIsFE3RnjKw4ynhKca9BoHabYlYH1FyfPMp7Y
vwbOsKVyF5NPL+smnOBbg8d43g0ajAvLzaUlhdaAf1jONw3T93roWCd5bA2G
87+HPXhPAVU9L9OTJ9cgk3k1vewdVj/3hUyfPLUGo4W8F0KwfqCx/8V9KeU1
mPee1NmDvd/h75L3SuPX4ALimpDB3ltDl9xMac01EJdLnDqMvZ83no6syVqv
gWb3h8wXz7D6dokaLme/BoFy5enJWD4tHfwreMppDfDZz44mYvl2P+vQhdNe
a8AnUvNH5AHW/zQbxilErMEJDqmXVdj7VcNQraRasQZHj+csP8bqw6GQRD8N
/nUQyr/8xksYqzcW75ePC6/D/Tm2+N+CWP2Sy3dnF1+HqYfI/+JhTD5U5UA5
vQ7va0aGRvdjchgxvKG3DuYXyhcesGD1dkdc4pn/OuRJC6v7zmPzNlnuvUfQ
Oiw5BDcNT5PhQJ7qEZPH67D1b+q+4wQmt9LnEXi5DqZhrwYvDGHybx60hdnr
IMy6dqYHmz/qov3uxRSug7PCi5uGnZi+c/C67+d18HxUW17ViskPxsyh2nVY
NAkyY2jA5L6lP0h96/B61HZIuYwMvBerTb78WodfbjycH7D5qPZYS1fi6Do0
f5Nn3cTmKd6eH40O1HUIfKrS/D4fk8vvflpj2oDBL7Xdvdj858bOKDXAsQFf
D3Id6cDmQ95RzqzqfRsgo3OjexabJ2vLD4i8P7QBTIELFubY/OkWI5Ty5MgG
WAfZm1/H5kteV4lDN8U2wDEqUDwTm19r1U/FXpLcgOnolDbXWEyf7wyXotwG
pH6OezUQjekvaYTzKW2AfJ/8Ws4LMtR812f4p7YB+LeeTA6RZHB9eznoj/oG
uDC+/J36DNO/e2W7WRuzR2mOvxWbv2sMb/jk/Yf97763/3oYpi9+azHKZAPS
PS5+3o/N+7w0d928LTcgx966rP0hpt8bPGFhtwF7nHg3rwdj+oXh9njHDRhw
Dgr3uI/ph8UMCrttwMLZC4M7/pj+lSRzJs8NUPSmP+noi8k5C/4jBG6AKN9X
AZIHJncjqtq/2oBNJ1wBlx0ZcnI1OIYTNkAsZcdGyZoMsdOff9umbYCq+89c
W3MyODklPLLJ3YDLr77rHbtEBm6Ha53mtRtwmrar2EadDPZWq1cvzm3Ay0eQ
qiCKzfe6h56qaW2CFNbt2I51g+7xq728q5twYXH526pbNzg0Lxayb28C9/uQ
YDr3brh/I+QJHe0WJElvGax4dMMbpn1XNxi3wKcj8i/D7W4o/pCuMs++BXb2
M7pPMO68IL93dO8WdAnnverz6obJiYbpHwe34FVEwIc4v26ge3K5vktwC8pk
OnX0/LuBX3w8sVF0C3hkxX02fbpBscXHq/zEFlQMR/lLeHaDoROTwSfZLVg7
Mzl25mY3hGaJ/01S2wKyn06I37VumBd3tfMy2QKaMNXUuIvdwPx9W9nFcgvc
q/c2fNTtBmHnCG47uy04cVLiT4tWN5hl59fpuW3BG9toh+0z3VAjQRUVebQF
jw6YZBiId0P0Ce8pYvEWzFj7p7rTdENeK0Nd89cteFrMdjlxmwRNLq8TKqu3
gF0jWmZ8jQRbOV/0stuw85MUoh7NkcBecis/6M8WfDm7+op2gAT32sIf+0xt
AYMk3bBlDwleux62dVvYgl6p68PfiSRoy1XDmW9vgb4PVSCphQTjeh2TBrTb
8IvexJRaT8L6R5taDaZteGLxQlWmmgTyJx94yuzbBmHLmlrmUhL8186lJ3Zo
Gw7+rFtr/kQCJ7c0kcNHMH2+uLrufBIk59WSGSW34YHkuFBcJgkYpeiVfqlv
w6Y11/7lNyTok3q6HeG5Dc+bH1hbBpLglMJDSQG/bSg4fitH+y4JItQCrfID
t8GgS4qJ0xuzT8P32dmH27D4i13b5TYJQO92eceTbbBmvUNn7E6CN0auMzbP
t+GA9aB3pisJliyuH56P2QadtP5AXWcS6F+11bsfvw16PUO1wjdIkOlkEcCZ
ug13z0yW5zlg571lnJvyfhuI+0lJnVdJYOlrMCCdsw1DQ6uzKVdIUHL/Alt1
4TaM8Bye+WtJAo7H585c/LwNMmI1CV9MSdi8fMb197dtqKexZpIzIkFNrEKi
R802/NP6rVdqQAKvdIntF23bWF/kzH1VkwSdOSKSQsRtOD7vVZoNJBAvErD6
2IPZ9+vx9roqCQZquMsJw9sg33a80V2OBOq/Nv25N7YhrMg0WVSQBLhDrVsv
RXegLOW5554NImjTs2296dmB+Noh+9KbRKg8JhbkaP4XSOY0H94IEMBbfU+j
VPc/0Iz+Nr6V3gHMcQKeWgk0aFQYPW5XaYO+otBGsgUtatedD2wqaIH4Uj7G
QnY61HHohoqbSRNsl3IfY6ygQydTqIo+nA1gN0hmwfvvQWwOLtdPVNZC6UxD
f40kPbpzhSburlg1cAoFe4jO0iNlzsOd5IRvwHwp9Q99NgP6RL7FUKtdCm6B
otGNuQyIbSws4bdyKRCys/GPCxhQ/TH0dUK8FOLoSuKZShiQ2B7mpyXMpXCs
pOUiazUD4ljL6zzb8hk0DiyVc1EY0OmbpwRv6X2G+4OasXy0jIhD+9qNS6Yl
2DzZem5gDyMaGXv+Vfp8CWgpXlxIZGREdgqaNfKKJcD+wkJXgJ0R0a7xVX/j
LYFE5E4jdIARZZR8p4v/UQxl6XFuYlKMiOzJ7MpuXwzLztOashaMSPL0kST+
0CKYb7rvfdKaERW/4OQX8SmCaZF9meK2jGhormKJ60YRjAyeYTp6nRFJLLv8
S9UuAsKlyO/ctxnRgUCmf/zsRVCgIvvf8hNG1Hlkjo6S8AlcWHzMSssYkYbD
TZkv3z+CoyPrk6JyRnT0hkb33fKPYF+fUlZQxYiIJ9NYjPI/gkVg86EPDYwo
/Of+7ujoj6C9ePBnHIERWflfkqG58hHEfpTb3Z1kRPtbHG0q/hWCkKJhtPcM
I/qgs/8qYbwQ+GNGa2/PM6KC6gU3145C2G/AIeKywoi+R54xUYwvBFzOW2PH
dUbkThcdTrhfCGxMio/stzB7tcoaWhwLgdGhteTKLiO6/WXw18NLhUBXe2XM
koYJuWuMGtJBIfwVWOYx28OEOna1YzVlCmHLP+y8MSMTKli4/3VUqBAW5T9+
0GNnQspWwixzdIUwG63Zd4GLCQn3kcONlwtgcr6PWXMvE5IIGC7S+lMAo3o3
VRAPE1rUGGbHkwpgKIvWRe0gE4qaVYzgqSmAqi6tezGtTOiZ0CMzEe1s0Hdi
b/+vgwldSrczUTmVDf003YdZCUzI82zu8dP82bAmZ1ceRGFCq7/kzpMWskA6
1n/r5hAT+uH10XfrdRakmBf6aa8xIbGhP4s3Zj/A/eGD3rtHmdELn4aDQgmZ
wO7/u6FMlBk9vfD21EJoJiTszdzvdZwZ9WQ2O5/2zIRSjdMl0yeZEc/mz9nD
+pkwn2Gw3KvEjE7VmxA06TLhikvI7SIDZpRYytSXapMB+OWZmzfuMqMDLS+q
liXeg0NFLbpyjxk1xCdFle5/D+GhcfsuP2BGWjHfzlz5lw49BzS+qocyo30K
tc+syOngrpZALxjNjESDlNsUA9MhJVQ7kZzFjOjam/aGdL2Dhv8E3dtymdHx
p7LXdL++g+kDK6iugBldvDMbQpv+DhRzUscLS5jR+VDL+E2fd9DZuSb3rIYZ
fZLGiYkffQf/DmS0nOtjRhNqzmcnAt/CsWH/ROUBZpSZ8Cv8ostb0M8xdJf5
xYyuMe2nMJu9hTdqO/sERplRrUBkzITcW6hiII3vm2BGr1uVDW4KvYXRzg9f
WaeZkUT0ORFB3FtgfRMYQTvHjNKX9L1pad+C7FVj240FTL75vMprOQ1MT0ic
WlhiRiW5/COxE2lwb/kv/fgqM6phqDtkOZgG7yrIvT83mNGlA4wpmeQ0aAnN
yeneZkZvZPuJvh1pMP9fUGDrX2ZULpD1rLUpDfYfNDWspWVBOZmLOgrVaaA6
LClSRs+CrNJyi4tK08Auh3atgIkFbV88y/grLw1q1K6I8CuxoDfnvpV4LafC
46+TR4dUWFCgA8GubyIV9BXvCL1XY0FG3g5VewZSYW/xrqATsKBj6reoae2p
0CvzROCkOguyFi99TVORCkl5e/mpmizInk/8lEB2KthLJPOVXGBB/zz32EjH
psK8cNEBNQMWJKP777vr9VQoSVXjpTFkQVpK+91H9FLBn795f4MRC8qUnq8P
lksFRt6f3PrmLOhKpkpI8lYKCLAwsltfY0H4vD0qEs9TYCQ0ilXIkQXZjdlR
tLxSIIvuMMuoEwt69dOrvc0yBeR3ZBjd3FnQ21vX4oXEU2DL7xu97G0WxHqp
yYmTKwVqVjX3rNxhQXu8vMVvrSWD/oIFzb27LIj5l/2TsqZk2Os2+hfusSAT
Pv/3HB+ToW/SfXfPAxbUbmlfpZ2QDNdGHm49e8SC3vUZinLcTgZ/Sv5K4gsW
dNIj8XaHSDIgI+Vl25csaOi634MQXDIwdtUtirxiQQlr/00d202C6Jbe+dwE
FuRs/Y/vTE8SZJXTTpVnsKAt+jn622FJ4K4cMfEgiwV9YXjM03EnCeQ/845r
5GLxoTlSrGGXBNUFkn/aPrKg8+1ZUQyqSdDz9vLgQDkL8oicSeueS4QkwaGB
1CoWNFKeb3OwPxHsE136r9WyIL6jwnOMTYkwF/ugd6aJBeXeicv5lJwIRdys
PYXfWVDZ65Zpt/BE8HseS77TzoLqgqosBnwTgf5JNnGbyIICPDuPLVxOhFZ6
eUI1GbsfNqS+2vOJEBVc1fmwF7OnRl8pUjkR+AO629gGWRDt5ApTiGAijKzb
tHb9xuLzKXNKfW8iZHlNtsSMsCCzDO+eAYZEcF/0bDYbY0H1V8kn9TcT4LT7
buPhScweq0slt2YTIKvR6eTOB1b04/X7sWsPX0HmsS8/WnJYUcvtxypmHq8g
PYwh7FU+KxpyPP/gp+UrSNF5NyxdzIpcP0zqhsi+glcdA6+vVrGi8aPNyvif
sRBC+Y+2mcyKjJyILXGysWA1Jt8TTcuGdEg+5+bHX4L5+YcPr9CzoTBxw3vv
iS/B9ANRVpKJDXELTNqpVrwEI2f3Zw3sbKht1OAFQ/RL0J77gNYPsCGav6uX
01VegvwqX661NBvCv1Rp+PkmGk6ZOptLyLEhIXlCyOrjaJD58oVh7TS234z6
nwve0XDirondCxU2pDJk/9bNKBqO7kby1GmyIYs6TlTKHg2cDLRBx63YUBz9
+AmmR1Hwd65daNyGDXnFH+OIuRMF8z1vat/bsSH3M2K7odeioDNLdo+wIxvy
sY5oatOMghf6do/5b7Ohh3w2/Di2KMDFVkdwh7Ehno7GWGPxF7BXBOsmi9hQ
JGuQxvbNSOA9t13UxcqOAliHs8vLnoJQem22+Xd2pHHfXu7xnRA4PFcSeTKA
AyV4pXqZ/vCD/mljO5n7HEi8pTbnV74fJEwunToVzIHOFN4xsAn2A75R2T6l
MA7kkxlTqSCG8UCesEYMB3qTtYW7aOsLfN/ff7HI5UBPzPfcDGzxBr6M2OHH
Axzobu/W52M9ntD/7nTJ018cSOHyBnNGhickpJEeRwxzoGd0pNfa3p7Al4Q7
+XKCA6W1Rnw7yItxTIRP8jIHagjMzjlz5TYcCn7EVsLGifbzPS/p7fKAgzZe
CsNnONHYgOXppl1naB2J2qbgOVHBVAm6WeQMgU75ta3nONHopStJ9dedYeTO
uEHJBU7kEvRhebXJCfLCzR3DjDnRnvKOvq27N+AKzvvkPVNOxMH1e4YqegO4
X0cv3bLgRAvL4WEOXY7g87b1vqUtJyJYVz8ZFXYEVKYWJ+XKiRzximqoywGW
zlrYCLtzIp99NqYbgQ6QUe8tcuA2J9r84WB0S8YBWLsKCml8OdG2+VP9vMRr
QB4TaukO4UTxLLT9A6/s4bHr2ectoZyoUMTBMNTSHlQWLUwqn3AipYuBNFVH
7CFl5+VQ5nNOZCiDjKKzr4LTPobNuwmcKH9jW3m70g744o9Wuydzol2F/x4I
PbKDDkF86LU0TjT/W9JfR88OTp3w5TbI5ETeGpOFreW2sIOmJISKONH3gqNK
MyevQJR7h2XTd05E05AZ9dTOCtRXpoTK2zkRfVdXuRyDFazeZZwo7OJEIgd3
nY9lW4JlKNyJp3CivyIWKTqzFiCa9OmZ2zAnsgrbX4LszKHnaOelq6OcyPne
ieOyW2bw9MP0AdMJTtSffGaNJcYM5otE3sMcJ7L5zq/wotEUvnx/VbF3kxOF
EA4cklC5DKx7bhSQtznRcOftqnejJmCtppz2+i8nutVbUJARYwI0hf0P+ei5
kGzBc4u5dWPQiT2iJ8zFhXSuj5Tf+G4EA1eyf8iJcSEnP4pGo4chSL/xb1s+
zoX8nDmj+iQMIYioV/n5BBfSreyzePP9IohqzqepyHKh68166tnf/oObEqed
zp3hQpfuCo+npOhDjT295R48F6K7GlTLwqMPe5Moeo2IC7XeD85HEXpQyukn
o3OeC3kqd1wwCdKFf8sVa4aXuNDPsH7lr4+0wUjq+eReEy7EMe3KZ8epDe8d
bfvJppi9k2ZaaYkXQPsHbZW5NReKOI5XK6o7D9FV50PtbnAhuKXJ+0BDC0Se
EvbdCuRCrydP2UfZqINP3VuGU0FcyCul7mHuxjlo2fZcXw7hQjVLAuYVsefA
zZ1nwPcJF+q7XX6/ugvBZ2PLdw9iuJAYgUm3MQ8PFwRHZV9kc6GeZzuLT+6o
wKknDRkReVzIMGiR62ezMvAvvecLL+RCWX9Ieyz5lYHaeJ0+9DMX6iyf6Jr8
rggJNyd6/Wu5kNX+Bva/OvLwqLdZ36+BC6VyloYafzwN7ueyar2buVCkaHxR
58HToMHjnHurgwvNuF3t6KLKwWzF9H3HH1xomi/46PloGeg51rZ87ScXOtsb
/Pz6E2moicp1uvqbC6k8Mna6HyQFrxzcjKzHuBAvY5xU7x1JCOrUb7aY5EJ7
Gbu86H1PgIuylJrZDBf6hjqeTjyWADz7vJjRIhfKmHJ+29l+HMR9OhMurnCh
hkuLm2J0x2HvUAGXwToXOnlIEn9E/RhMFHtsXtjlQoy0xn8pw6IwxSn+RZgG
h/7sUEinzonCL403t9/S4pCtyGEalg8i0JLvN55Cj0PfvR5f1XgoDJUjk2kC
jDgUfjSH8mHzKBQdsLBKYsKhnCZUsXLnKCQFqxDiWXHI8w+tYLq7ENy+vPU1
FodDPzxLbI9O8oNjuIvXvr049G7jbrHL1GGwru6XfrkPh9qEG4mxU3xwXqI8
/QUvDs0EZJT8Wj4IfLsBkeH8OKT9VN63RIMHuE7NXmARxKETc6fyGK/uB/ob
1nRPjuCQcSf9xcfB+2CeoOYbKoxDersUv04CN/xhyJejF8UhfBxdqiwTN/Sp
CsyGiOHQmc0L6Y7aOKh/v2sXJI5DPmcVftD3cEDZj5uH/0ngkGsBU+PGK3Yo
4PxFCZTEIUuiZVWwExu88avSDZDGIQ41mmakxQKR+dIMWzI4tPRRvD5MmxlC
RlKq/eRwKFZXVKDdiAnc9B/I+8jj0Neoe+kG9xhAbuD7owEFHNLVtjpyMZse
1pz3U5ASDs2+Ku6q6NkDQWHZ3myqOBSv9tJ3WpYOtHhXGm+dwaFCknR5rg0t
sGbgeXvUcOjsBPPkg2c0EFvXjXXNOLQglbdkObeLt7gkyMR4DocCb+Yspjrt
4AWHnMxc1XHIrUr9Zer8Fv6Pe/EHggYOZV4arngfsonP2t1dV9DCoYO2Os4B
khv4mxHa2onncajSu0fBbGoNf+pwzBsabRziyQ2oVKxYxVcoi6u06WJyvrxo
weRlfHCz51NZfRw6FpjVUvx2CX/etPLHKwMc2vwue6790yKecMfI384Qh159
YXZinVrAv6JLbm28hEPTlweGjbTm8ZbRE3ySxjh0Y+pumH7mLH604F756mUc
GhHcZjTzmcJnn21mszLDoU6+Xs5bYxN493Zu6xpzHLKjO/Nd1W4cvzGVuRNu
hflv9KJ90NM/+Eq/RX2qNQ5Zo8/Bm0oj+BAmteTLV3Aof+neubL1Ibz268dz
32xxqOkH0ex04m88hxjxrNBVHDpsYPk15u4gnlR8+HmoPQ7RkI0EIsIH8G/U
HX9NX8OhVS4b0QOdP/A2xI/ShtdxaM02oG1Eow8vbLd9/7MjDv1M3sj3G+jB
T8xrdfE5YfoXRvlvPqPg8wKjjgQ545C5zq8/VcZkvGKiWI2uGw49u9A3LS5F
wm9L3MJ9vIlDj/XOxKzJEvE1Zd/seDxwSCrzje6CMgGv23ORdug2Dp0LPjTQ
mNOO57qecEnrDnZ+g74qJnIrnrw8+jbHC4eyHmn4D3N/x1/h9lf39sUhZ6/8
a4d/NeJF0hpe9vvh0Bc56ev33Brwk9Jcf8Afh1oOaJfn8dTj8ystTmcE4FBZ
kYAgqbcW76n//iFrIA7VNjrPzH6qwSsNzHd73Mchp1P9YQza1fgdZxVRygPs
fvU23FO2rsTXbjz0Ug3Goezs4+74tHL847DOhtQQHCKUO2vr0HzD6/Ee4mF4
hENFj02ko2+V4XEZ1667hOKQ2HmLw86LpfiEug0GhSdYfsuf2ssnXoK3vaRh
mvAUhx7hJDb9hovwokORmf/Cceh38pMFjhNF+P8BymvNgQ==
        "]], LineBox[CompressedData["
1:eJwBcQGO/iFib1JlAgAAABYAAAACAAAAqH7Q9G6gEUD+rBFRXlm9umQq1aer
oRFAtJ5aJOeNFbsQAZuHN6MRQEnQ054WuyS7wFuyBmepEUDllNYDu6AuuyAR
4QTGtRFAV3HlyPENMLvgez4BhM4RQH2yXsLGqiy7jFIE4Q/QEUCD/sEYzzQs
uzgpysCb0RFAV5Eq0ny3K7uQ1lWAs9QRQCINNq/Rpiq7QDFt/+LaEUBE6jhi
py0ou6Dmm/1B5xFA2jEt86feIbtMvWHdzegRQMVDiXRh9CC7+JMnvVnqEUB+
fkLL9wIgu1BBs3xx7RFArY+PQagVHLsAnMr7oPMRQKuvZgldjBO7rHKQ2yz1
EUDcLcRCY0cRu1hJVru49hFAzmkRSpnpDbuw9uF60PkRQDb7iJcwTwS7XM2n
Wlz7EUCir/ZIa7b+ugikbTro/BFAxpG9+rad9Lq0ejMadP4RQMH01WidsuS6
YFH5+f//EUC0pb3TNXICulFWsoo=
        "]]},
      Annotation[#, "Charting`Private`Tag$306987#1"]& ]}, {}, {}}, {{}, {{}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.011000000000000001`], AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJxFUwtMk2cUbZEC7hEmqRNFF9DBnELnY7JYO85fHpsPliGMEsMkPGxoUoaT
x17ZJmOBzeGjDNIYh6CbjhW28HKA1KGIY+1A6eMvszosAuVhAYFCKRVw///T
dCf58uUm373fufecG5B6NFbsxmKxIqlD37JGP5n/R0ZcMC8culNxFTcnB/g7
OPdBWvb+cZpUwrblV3NE6b8Ql7wTajxyHfczify74geQVbp/ul/WhsQKwZ70
ehNChruzloLbceHYiGWxrQ+mWtvzUtMtXD0d3VZ44iECVXH5gsAOFP7++bff
l/QjnsFfGFNxM876DiAikoYKnKFPhAF9A8jVRq05nKNG1JLtvKRwEAw989+o
XnXmq8xnzdjKbQo/trULt3hW0ZzODKa86jaaY9683KYcQheDO5iTKNkrU4fB
0BvuRlmpVig6NQIR878GNnVDdtCTUdDVuE0aZ/8WFPSLNmcWaNHowzuxMG7B
BsU/xZ9t0DnnMYbO+YYydOoQGrElvIg/jkwmQY/N4hxZ/KYJaJjv9JB8MT1W
pp7AKgYk8s6JbgYWP4ZfT2vKuB8JflKMl10widiaTbP8WBI7j+a+drhuEpLd
x+XWdBIhTMIUyn0GXxWWk8j+xlp0KWHKOV8SLPllm0Q5BSHzwICGClqAKdDs
+0UG6Ktr5d4Hp11xcksqm7wyjYx6ddAPGQbkdVysmfO0Ijrtxuse0QYMGXeX
LJ60uuqZHiVRGTNY/V3ixebVBkjnXwh8Rfx/bPdsP2NRzTj1MMCX6xbmvX4W
HzMwwId6nSObBa1OXL4Bz4RGnzS621zx2UhaYJuL31KC/N5P4zYEvLtyutTf
gCNSXqsiaw7XqWn1tJKg3bODb0c2Pd4sEjHl53cau+2ueTbV7Vpjem8eLSM/
FvFa9Fj/523HoHHepY9A+5zCK8QBRu5wPd7vPZAQnOcAW++77RRbD9HEh18W
zzhQXUVDB7nH43t3zz1BmL3va+8wHXpe+uANf+ECrilpaJEYFqnet3YRa+ls
Xy28Du3q365ZRPK6FT9vT9ZghlIrJeSpy4+9Dxc2jsazCEvupaS3H3UijVLD
h8cmqGapjlUY9a9+S+DhRuxhDNGBvVGSg5VP3QhqGaiNaIcgvZ5SeAWxXP8G
ijgx+v3N7gRjT4USBS/mOmqCOc56zbjyi/64WMEhvJkGGrHumjRNyvMglve1
AS/H1aakdnkQy/xqUUdFQds8iQe9NH5DVRZtOE9iI4MqsBh4EYzc3Er8B2Xk
G/w=
       "]]}, {}}, {}, {}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0.10000008979591837`, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->FrontEndValueCache[{{Automatic, 
      Charting`ScaledFrameTicks[{Identity, Identity}]}, {Automatic, 
      Charting`ScaledFrameTicks[{Identity, Identity}]}}, {{Automatic, {{0., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {0.1, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {0.2, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {0.3, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {-0.1, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-0.08, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-0.06, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-0.04, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-0.02, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.02, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.04, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.06, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.08, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.12, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.14, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.16, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.18, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.22, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.24, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.26, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.28, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.32, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.34, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.36, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.38, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.4, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}}}, {Automatic, {{0., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {1., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {2., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {3., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {4., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {-1., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-0.8, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-0.6, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-0.4, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-0.2, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.2, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.4, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.6, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.8, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {1.2, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {1.4, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {1.6, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {1.8, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {2.2, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {2.4, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {2.6, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {2.8, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {3.2, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {3.4, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {3.6, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {3.8, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {4.2, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {4.4, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {4.6, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {4.8, 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {5., 
        FormBox[
         TemplateBox[{0., 0.}, "Spacer2"], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}}}}],
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->All,
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 4}, {0, 0.35}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.723917271485573*^9},ExpressionUUID->"578519c4-7109-4861-ac53-\
02805147de5a"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"Map", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"PVlimit3", "[", 
     RowBox[{"#", ",", 
      RowBox[{"1.1", "*", "eV"}]}], "]"}], "&"}], ",", 
   RowBox[{"{", 
    RowBox[{"100", ",", "273", ",", "300", ",", "323"}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Map", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"PVlimit3", "[", 
     RowBox[{"#", ",", 
      RowBox[{"1.4", "*", "eV"}]}], "]"}], "&"}], ",", 
   RowBox[{"{", 
    RowBox[{"100", ",", "273", ",", "300", ",", "323"}], "}"}]}], 
  "]"}]}], "Input",
 CellChangeTimes->{{3.686193194777458*^9, 3.6861932657887726`*^9}, {
  3.717422048778798*^9, 
  3.7174220518257675`*^9}},ExpressionUUID->"f6d10cc2-61c5-4a64-9daa-\
b44f6e2bdf2c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.425807875900244`", ",", "0.3322150501352861`", ",", 
   "0.31789225945504407`", ",", "0.3057616393425787`"}], "}"}]], "Output",
 CellChangeTimes->{
  3.723917279283237*^9},ExpressionUUID->"3ba3a6bd-79b9-4d18-95ce-\
531ee1625fd5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.41120660499211736`", ",", "0.3363367297560683`", ",", 
   "0.3248198311256967`", ",", "0.31504958118177157`"}], "}"}]], "Output",
 CellChangeTimes->{
  3.723917282177247*^9},ExpressionUUID->"ce8cc729-f073-46c9-be45-\
e8a174b562ea"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1248, 837},
WindowMargins->{{41, Automatic}, {Automatic, 15}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> True}},
FrontEndVersion->"11.2 for Mac OS X x86 (32-bit, 64-bit Kernel) (September \
10, 2017)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 548, 8, 27, "Subsubtitle",ExpressionUUID->"e2c70ae9-1e98-49af-8783-5ea05a5a9952"],
Cell[1130, 32, 7253, 180, 501, "Input",ExpressionUUID->"18c37f0d-868c-45d3-a788-304d056647e3"],
Cell[CellGroupData[{
Cell[8408, 216, 3528, 97, 70, "Input",ExpressionUUID->"72806972-8227-4095-878e-246ae9aac156"],
Cell[11939, 315, 38399, 720, 134, "Output",ExpressionUUID->"e52b3440-5893-48ac-82be-6fe27b1bd7ac"]
}, Open  ]],
Cell[CellGroupData[{
Cell[50375, 1040, 900, 28, 51, "Input",ExpressionUUID->"5d2c9118-409e-4710-8942-397b6efa7fae"],
Cell[51278, 1070, 145, 2, 31, "Output",ExpressionUUID->"0e80bf17-9978-449d-8648-2bebe6de7cfb"],
Cell[51426, 1074, 149, 3, 31, "Output",ExpressionUUID->"43a3fd48-9b33-420a-b116-88c3f1b85e65"]
}, Open  ]],
Cell[CellGroupData[{
Cell[51612, 1082, 1878, 47, 89, "Input",ExpressionUUID->"c08bf8fc-0d4d-4aca-b80d-7cd26eca9a1e"],
Cell[53493, 1131, 274, 5, 31, "Output",ExpressionUUID->"de60e478-26a4-43fb-bfbf-5c831f6e8cb3"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[53816, 1142, 887, 13, 27, "Subsubtitle",ExpressionUUID->"c9f1436f-cdcf-40dd-9314-4b71a38564d7"],
Cell[54706, 1157, 10061, 243, 720, "Input",ExpressionUUID->"44787964-f47e-4727-8cfb-667c0a939299"],
Cell[CellGroupData[{
Cell[64792, 1404, 567, 14, 31, "Input",ExpressionUUID->"56959b2c-253c-4f3e-8f3b-3409278daa7c"],
Cell[65362, 1420, 29245, 539, 239, "Output",ExpressionUUID->"46fc3b67-77f5-4438-9591-9cf29cf8dfeb"]
}, Open  ]],
Cell[CellGroupData[{
Cell[94644, 1964, 801, 21, 108, "Input",ExpressionUUID->"600f6439-ba37-45d2-8ac1-738879fafefd"],
Cell[95448, 1987, 31409, 579, 239, "Output",ExpressionUUID->"578519c4-7109-4861-ac53-02805147de5a"]
}, Open  ]],
Cell[CellGroupData[{
Cell[126894, 2571, 724, 22, 51, "Input",ExpressionUUID->"f6d10cc2-61c5-4a64-9daa-b44f6e2bdf2c"],
Cell[127621, 2595, 274, 7, 31, "Output",ExpressionUUID->"3ba3a6bd-79b9-4d18-95ce-531ee1625fd5"],
Cell[127898, 2604, 276, 7, 31, "Output",ExpressionUUID->"ce8cc729-f073-46c9-be45-e8a174b562ea"]
}, Open  ]]
}, Open  ]]
}
]
*)

